@@ -1,3 +1,10 @@
+"""
+$description Video content from Telefe, an Argentine TV station.
+$url telefe.com
+$type vod
+$region Argentina
+"""
+
 import logging
 import re
 
